Roadmap
=======

* Future

  * SQLAlchemy/Spark as plugins

  * Streaming - I would like to be able to support streaming data subjects (like Kafka).

  * Auto-documentation - The testing framework should be able to support building
    documentation by collecting test scenario and case definitions.  Documents could be built
    to look something like Gherkin.
